==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileListBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProfileListBuilder extends io.fabric8.openshift.api.model.tuned.v1.ProfileListFluentImpl<io.fabric8.openshift.api.model.tuned.v1.ProfileListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.ProfileList,io.fabric8.openshift.api.model.tuned.v1.ProfileListBuilder>{
  public ProfileListBuilder() {
    this(false);
  }
  public ProfileListBuilder(java.lang.Boolean validationEnabled) {
    this(new ProfileList(), validationEnabled);
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProfileList(), validationEnabled);
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileListFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.ProfileList instance) {
    this(fluent, instance, false);
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileListFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.ProfileList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileList instance) {
    this(instance,false);
  }
  public ProfileListBuilder(io.fabric8.openshift.api.model.tuned.v1.ProfileList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.ProfileListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.ProfileList build() {
    ProfileList buildable = new ProfileList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProfileListBuilder that = (ProfileListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/ProfileListBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProfileListBuilder extends ProfileListFluentImpl<ProfileListBuilder> implements VisitableBuilder<ProfileList,ProfileListBuilder>{
  public ProfileListBuilder() {
    this(false);
  }
  public ProfileListBuilder(Boolean validationEnabled) {
    this(new ProfileList(), validationEnabled);
  }
  public ProfileListBuilder(ProfileListFluent<?> fluent) {
    this(fluent, false);
  }
  public ProfileListBuilder(ProfileListFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ProfileList(), validationEnabled);
  }
  public ProfileListBuilder(ProfileListFluent<?> fluent,ProfileList instance) {
    this(fluent, instance, false);
  }
  public ProfileListBuilder(ProfileListFluent<?> fluent,ProfileList instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProfileListBuilder(ProfileList instance) {
    this(instance,false);
  }
  public ProfileListBuilder(ProfileList instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProfileListFluent<?> fluent;
  Boolean validationEnabled;
  public ProfileList build() {
    ProfileList buildable = new ProfileList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
